bind_type_annotations

Function bind_type_annotations 

pub fn bind_type_annotations(
    root: ExprId,
    arena: &ExprArena,
    types: &mut TypeTable,
)
For every node that has a type_annotation, derives an InferredType from that annotation and writes it into TypeTable. For Let nodes the type annotation applies to the rhs child, not the Let node itself (mirrors the existing behaviour exactly).