push_types_down

Function push_types_down 

pub fn push_types_down(
    root: ExprId,
    arena: &ExprArena,
    types: &mut TypeTable,
) -> Result<(), RibTypeErrorInternal>
Pre-order traversal: for each parent node, read its type from TypeTable and push derived types down into child nodes.