RibCompilerConfig

Struct RibCompilerConfig 

pub struct RibCompilerConfig {
    pub component: ComponentDependency,
    /* private fields */
}
Compiler configuration options for Rib.

Fields

  • component_metadata: Component metadata that describes the worker functions available.

  • global_input_spec: Defines constraints and types for global input variables. By default, Rib allows any identifier (e.g., foo) to be treated as a global variable. A global variable is a variable that is not defined in the Rib script but is expected to be provided by the environment in which the Rib script is executed (e.g., request, env). Hence it is called global_input. This field can restrict global variables to a predefined set. If the field is empty, any identifier can be used as a global variable.

    You can also associate specific types with known global variables using GlobalVariableTypeSpec. For example, the path request.path.* can be enforced to always be of type string. Note that not all global variables require a type specification.

Fields

component: ComponentDependency

Implementations