infer_function_invokes

Function infer_function_invokes 

pub fn infer_function_invokes(
    root: ExprId,
    arena: &mut ExprArena,
    types: &mut TypeTable,
    _component_dependencies: &ComponentDependency,
) -> Result<(), RibTypeErrorInternal>
Converts SelectField on an Instance type into a resolved Call, and InvokeMethodLazy on an Instance type into a resolved Call.

Run on lowered IR inside the same lower / rebuild_expr boundary as crate::Expr::infer_types.